# Changelog

<!--next-version-placeholder-->

## v0.1.0 (2022-08-10)
### Feature
* Initial audioinfo ([`78816b7`](https://github.com/haoxiangsnr/audioinfo/commit/78816b72eb4a00ca1ded67be2dcec522f064f96e))